@@ -70,12 +70,7 @@ fin_exp =>
    )
 ,
 end_of_string => qr/\z/,
-number => L(
-  qr/\s*[+-]?(\d+(\.\d*)?|\.\d+)\s*/,
-  E(sub{
-   return 0 + $_[0];
-  })
- )
+number => qr/\s*[+-]?(\d+(\.\d*)?|\.\d+)\s*/,
 ,
 left_parenthesis => qr/\s*(\()\s*/,
 right_parenthesis => qr/\s*(\))\s*/,
